@@ -22,8 +22,9 @@ chk_sqlite_conn <- function(x, connected = NA, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  chkor(chk_s4_class(x, "SQLiteConnection", x_name = x_name),
-        chk_s3_class(x, "Pool", x_name = x_name))
+  # pass x_name when implemented in chkor_vld()
+  chkor_vld(vld_s4_class(x, "SQLiteConnection"),
+            vld_s3_class(x, "Pool"))
   if (vld_true(connected)) abort_chk(x_name, " must be connected.")
   abort_chk(x_name, " must be disconnected.")
 }
