@@ -27,11 +27,10 @@ tz <- function(x) {
   tz
 }
 
-
 sys_date_time_utc <- function() {
   date_time <- Sys.time()
   attr(date_time, "tzone") <- "UTC"
-  as.character(date_time, format = "%Y-%m-%d %H:%M:%S")
+  format(date_time, format = "%Y-%m-%d %H:%M:%S")
 }
 
 user <- function() {
