@@ -1,9 +1,10 @@
 test_that("chk_sqlite_conn", {
   expect_error(chk_sqlite_conn(1),
-    "`1` must inherit from S4 class 'SQLiteConnection'[.].*`1` must inherit from S3 class 'Pool'[.]$",
+    "`x` must inherit from S4 class 'SQLiteConnection'[.].*`x` must inherit from S3 class 'Pool'[.]$",
     class = "chk_error"
   )
   conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+  
   expect_null(chk_sqlite_conn(conn))
   expect_invisible(chk_sqlite_conn(conn))
   expect_null(chk_sqlite_conn(conn, connected = TRUE))
