@@ -1,9 +1,6 @@
-context("drop")
-
 test_that("rws_drop_table works", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
-
+  conn <- local_conn()
+  
   rws_write(list(somedata = readwritesqlite:::rws_data_sf), exists = FALSE, conn = conn)
   expect_identical(rws_list_tables(conn), "somedata")
   expect_true(rws_drop_table("somedata", conn))
@@ -13,9 +10,8 @@ test_that("rws_drop_table works", {
 })
 
 test_that("rws_rename_table informative errors", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
-
+  conn <- local_conn()
+  
   rws_write(list(somedata = readwritesqlite:::rws_data_sf), exists = FALSE, conn = conn)
   expect_error(
     rws_drop_table("somedata2", conn),
@@ -28,9 +24,8 @@ test_that("rws_rename_table informative errors", {
 })
 
 test_that("rws_rename_table multiple tables", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
-
+  conn <- local_conn()
+  
   rws_write(list(somedata = data.frame(y = 2), moredata = data.frame(x = 1)), exists = FALSE, conn = conn)
   expect_identical(rws_list_tables(conn), sort(c("moredata", "somedata")))
   expect_true(rws_drop_table("somedata", conn))
@@ -40,9 +35,8 @@ test_that("rws_rename_table multiple tables", {
 })
 
 test_that("rws_drop_table primary key deferred", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
-
+  conn <- local_conn()
+  
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER PRIMARY KEY NOT NULL)")
 
