@@ -1,8 +1,6 @@
-context("meta")
-
 test_that("make_meta_data works", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = as.character(1:3))
 
@@ -28,8 +26,8 @@ test_that("make_meta_data works", {
 })
 
 test_that("read_sqlite_meta creates table", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   expect_identical(rws_read_meta(conn), rws_read_meta(conn))
   meta <- rws_read_meta(conn)
@@ -41,8 +39,8 @@ test_that("read_sqlite_meta creates table", {
 })
 
 test_that("meta handles logical", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(z = c(TRUE, FALSE, NA))
   DBI::dbCreateTable(conn, "local", local)
@@ -57,8 +55,8 @@ test_that("meta handles logical", {
 })
 
 test_that("meta handles all classes", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(
     logical = TRUE, date = as.Date("2000-01-01"),
@@ -80,8 +78,8 @@ test_that("meta handles all classes", {
 })
 
 test_that("meta errors if meta and then no meta", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(z = c(TRUE, FALSE, NA))
 
@@ -96,8 +94,8 @@ test_that("meta errors if meta and then no meta", {
 })
 
 test_that("meta errors if no meta and then meta", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(z = as.character(c(TRUE, FALSE, NA)), stringsAsFactors = FALSE)
 
@@ -112,8 +110,8 @@ test_that("meta errors if no meta and then meta", {
 })
 
 test_that("meta errors if inconsistent meta", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(z = c(TRUE, FALSE, NA))
 
@@ -128,8 +126,8 @@ test_that("meta errors if inconsistent meta", {
 })
 
 test_that("fix meta inconsistent by deleting", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(z = c(TRUE, FALSE, NA))
 
@@ -152,8 +150,8 @@ test_that("fix meta inconsistent by deleting", {
 })
 
 test_that("meta reads logical", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(z = c(TRUE, FALSE, NA))
 
@@ -164,8 +162,8 @@ test_that("meta reads logical", {
 })
 
 test_that("meta reads all classes", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(
     logical = TRUE,
@@ -205,8 +203,8 @@ test_that("meta reads all classes", {
 })
 
 test_that("meta = FALSE same as just writing", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(
     logical = TRUE,
@@ -247,8 +245,8 @@ test_that("meta = FALSE same as just writing", {
 })
 
 test_that("meta logical logical different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- c(TRUE, FALSE, NA)
   local <- data.frame(
@@ -281,8 +279,8 @@ test_that("meta logical logical different types", {
 })
 
 test_that("meta Date different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- as.Date(c("2001-02-03", "2002-03-04", NA))
   local <- data.frame(
@@ -315,8 +313,8 @@ test_that("meta Date different types", {
 })
 
 test_that("meta POSIXct different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- as.POSIXct(c(
     "2001-01-02 03:04:05", "2007-08-09 10:11:12", NA
@@ -353,8 +351,8 @@ test_that("meta POSIXct different types", {
 })
 
 test_that("meta hms different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- as.POSIXct(c(
     "2001-01-02 03:04:05", "2007-08-09 10:11:12", NA
@@ -393,8 +391,8 @@ test_that("meta hms different types", {
 })
 
 test_that("meta hms preserves decimal", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- as.POSIXct(c(
     "2001-01-02 03:04:05", "2007-08-09 10:11:12", NA
@@ -434,8 +432,8 @@ test_that("meta hms preserves decimal", {
 })
 
 test_that("meta units different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- units::as_units(c(10, 11.5, NA), "m3")
 
@@ -469,8 +467,8 @@ test_that("meta units different types", {
 })
 
 test_that("meta sfc different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- sf::st_sfc(c(
     sf::st_point(c(0, 1)),
@@ -530,8 +528,8 @@ test_that("meta sfc different types", {
 })
 
 test_that("meta factor different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- factor(c("x", "y", NA), levels = c("y", "x"))
   local <- data.frame(
@@ -565,8 +563,8 @@ test_that("meta factor different types", {
 })
 
 test_that("meta factor 11 level", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- factor(c(1:11, NA), levels = c(1:11))
   local <- data.frame(
@@ -592,8 +590,8 @@ test_that("meta factor 11 level", {
 
 
 test_that("meta ordered different types", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- ordered(c("x", "y", NA), levels = c("y", "x"))
   local <- data.frame(
@@ -626,8 +624,8 @@ test_that("meta ordered different types", {
 })
 
 test_that("meta factor without meta then meta errors", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- factor(c("x", "y", NA), levels = c("y", "x"))
   local <- data.frame(
@@ -668,8 +666,8 @@ test_that("meta factor without meta then meta errors", {
 })
 
 test_that("meta factor rearrange levels", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- factor(c("x", "y", NA), levels = c("y", "x"))
   local <- data.frame(
@@ -707,8 +705,8 @@ test_that("meta factor rearrange levels", {
 })
 
 test_that("meta factor add levels", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- factor(c("x", "y", NA), levels = c("y", "x"))
   local <- data.frame(
@@ -748,8 +746,8 @@ test_that("meta factor add levels", {
 })
 
 test_that("meta ordered add and rearrange levels", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   z <- ordered(c("x", "y", NA), levels = c("y", "x"))
   local <- data.frame(
@@ -811,8 +809,8 @@ test_that("read_meta_levels", {
 })
 
 test_that("meta TRUE then FALSE then read with TRUE", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(fac = factor(c("this", "that", NA)))
   DBI::dbCreateTable(conn, "local", local)
@@ -855,8 +853,8 @@ test_that("meta TRUE then FALSE then read with TRUE", {
 })
 
 test_that("meta strips trailing spaces proj", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(
     logical = TRUE,
