@@ -1,8 +1,6 @@
-context("write")
-
 test_that("rws_write.data.frame checks reserved table names", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = as.character(1:3))
   expect_error(
@@ -24,8 +22,8 @@ test_that("rws_write.data.frame checks reserved table names", {
 })
 
 test_that("rws_write.data.frame checks table exists", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = as.character(1:3))
   expect_error(
@@ -35,8 +33,8 @@ test_that("rws_write.data.frame checks table exists", {
 })
 
 test_that("rws_write.data.frame writes to existing table", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -46,8 +44,8 @@ test_that("rws_write.data.frame writes to existing table", {
 })
 
 test_that("rws_write.data.frame errors if exists = FALSE and already exists", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -55,8 +53,8 @@ test_that("rws_write.data.frame errors if exists = FALSE and already exists", {
 })
 
 test_that("rws_write.data.frame creates table", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   expect_identical(rws_write(local, exists = FALSE, conn = conn), "local")
@@ -65,8 +63,8 @@ test_that("rws_write.data.frame creates table", {
 })
 
 test_that("rws_write.data.frame handling of case", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -85,8 +83,8 @@ test_that("rws_write.data.frame handling of case", {
 })
 
 test_that("rws_write.data.frame deals with \" quoted table names", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   locals <- data.frame(y = 1:2)
@@ -101,8 +99,8 @@ test_that("rws_write.data.frame deals with \" quoted table names", {
 })
 
 test_that("rws_write.data.frame deals with [ quoted table names", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   locals <- data.frame(y = 1:2)
@@ -117,8 +115,8 @@ test_that("rws_write.data.frame deals with [ quoted table names", {
 })
 
 test_that("rws_write.data.frame deals with backtick quoted table names", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3, select = 1:3)
   locals <- data.frame(y = 1:2)
@@ -133,8 +131,8 @@ test_that("rws_write.data.frame deals with backtick quoted table names", {
 })
 
 test_that("rws_write.data.frame corrects column order", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 4:6, select = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -153,8 +151,8 @@ test_that("rws_write.data.frame corrects column order", {
 })
 
 test_that("rws_write.data.frame warns for extra columns", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 4:6, y = 1:3)
   DBI::dbCreateTable(conn, "local", local["x"])
@@ -171,8 +169,8 @@ test_that("rws_write.data.frame warns for extra columns", {
 })
 
 test_that("rws_write.data.frame is case insensitive", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = as.character(1:3), seLect = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -182,8 +180,8 @@ test_that("rws_write.data.frame is case insensitive", {
 })
 
 test_that("rws_write.data.frame deals with quoted column names", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- tibble::tibble(x = factor(1:3), `[x]` = factor(2:4), `"x"` = factor(3:5))
   expect_identical(rws_write(local, conn = conn, exists = FALSE), "local")
@@ -204,8 +202,8 @@ test_that("rws_write.data.frame deals with quoted column names", {
 })
 
 test_that("rws_write.data.frame can delete", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -216,8 +214,8 @@ test_that("rws_write.data.frame can delete", {
 })
 
 test_that("rws_write.data.frame can not commit", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3)
   DBI::dbCreateTable(conn, "local", local)
@@ -229,16 +227,16 @@ test_that("rws_write.data.frame can not commit", {
 })
 
 test_that("rws_write.list errors with none data frames", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(x = 1)
   expect_error(rws_write(y, conn = conn), "^List `y` includes objects which are not data frames[.]$")
 })
 
 test_that("rws_write.environment issues warning with no data frames", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- new.env()
   assign("x", 1, envir = y)
@@ -246,8 +244,8 @@ test_that("rws_write.environment issues warning with no data frames", {
 })
 
 test_that("rws_write.list requires named list", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(data.frame(x = 1:3))
   expect_error(rws_write(y, conn = conn), "^`x` must be named[.]$",
@@ -256,8 +254,8 @@ test_that("rws_write.list requires named list", {
 })
 
 test_that("rws_write writes list with 1 data frame", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3))
 
@@ -268,8 +266,8 @@ test_that("rws_write writes list with 1 data frame", {
 })
 
 test_that("rws_write writes list with 2 data frame", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3), local2 = data.frame(y = 1:4))
 
@@ -283,8 +281,8 @@ test_that("rws_write writes list with 2 data frame", {
 })
 
 test_that("rws_write writes list with 2 identically named data frames", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3), LOCAL = data.frame(x = 1:4))
 
@@ -295,8 +293,8 @@ test_that("rws_write writes list with 2 identically named data frames", {
 })
 
 test_that("rws_write errors if list with 2 identically named data frames and complete = TRUE", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3), LOCAL = data.frame(x = 1:4))
 
@@ -308,8 +306,8 @@ test_that("rws_write errors if list with 2 identically named data frames and com
 })
 
 test_that("rws_write errors if complete = TRUE and not all data frames", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3))
 
@@ -322,8 +320,8 @@ test_that("rws_write errors if complete = TRUE and not all data frames", {
 })
 
 test_that("rws_write errors if strict = TRUE and exists = TRUE and extra data frames", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3), local2 = data.frame(y = 1:2))
 
@@ -339,8 +337,8 @@ test_that("rws_write errors if strict = TRUE and exists = TRUE and extra data fr
 })
 
 test_that("rws_write writes environment", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- data.frame(x = 1:3)
   z <- 1
@@ -351,8 +349,8 @@ test_that("rws_write writes environment", {
 })
 
 test_that("rws_write not commits", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   y <- list(local = data.frame(x = 1:3), LOCAL = data.frame(x = 1:4))
 
@@ -365,8 +363,8 @@ test_that("rws_write not commits", {
 })
 
 test_that("replace rows PRIMARY KEY constraints", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER PRIMARY KEY NOT NULL,
@@ -399,8 +397,8 @@ test_that("replace rows PRIMARY KEY constraints", {
 })
 
 test_that("replace rows UNIQUE constraints in unique key", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER UNIQUE NOT NULL,
@@ -431,8 +429,8 @@ test_that("replace rows UNIQUE constraints in unique key", {
 })
 
 test_that("replace rows with FOREIGN key", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER PRIMARY KEY NOT NULL)")
@@ -454,8 +452,8 @@ test_that("replace rows with FOREIGN key", {
 })
 
 test_that("foreign keys switched on one data frame at a time", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER PRIMARY KEY NOT NULL)")
@@ -476,8 +474,8 @@ test_that("foreign keys switched on one data frame at a time", {
 })
 
 test_that("foreign keys switched off for two data frame", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER PRIMARY KEY NOT NULL)")
@@ -493,8 +491,8 @@ test_that("foreign keys switched off for two data frame", {
 })
 
 test_that("foreign keys pick up foreign key violation for two data frames", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   DBI::dbExecute(conn, "CREATE TABLE local (
                   x INTEGER PRIMARY KEY NOT NULL)")
@@ -512,8 +510,8 @@ test_that("foreign keys pick up foreign key violation for two data frames", {
 })
 
 test_that("strict environment with extra data frame and extra column", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   env <- new.env()
 
@@ -543,8 +541,8 @@ test_that("strict environment with extra data frame and extra column", {
 })
 
 test_that("sf data frames with single geometry passed back", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- readwritesqlite:::rws_data_sf
 
@@ -570,8 +568,8 @@ test_that("sf data frames with single geometry passed back", {
 })
 
 test_that("sf data frames with two geometries and correct one passed back", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- tibble::as_tibble(local)
@@ -597,8 +595,8 @@ test_that("sf data frames with two geometries and correct one passed back", {
 })
 
 test_that("sf can change sf_column", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- tibble::as_tibble(local)
@@ -623,8 +621,8 @@ test_that("sf can change sf_column", {
 })
 
 test_that("sf data frames with two geometries and lots of other stuff and correct one passed back", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- tibble::as_tibble(local)
@@ -652,8 +650,8 @@ test_that("sf data frames with two geometries and lots of other stuff and correc
 })
 
 test_that("initialized even with no rows of data", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- tibble::as_tibble(local)
@@ -683,8 +681,8 @@ test_that("initialized even with no rows of data", {
 })
 
 test_that("initialized meta with no rows of data and not overwritten unless delete = TRUE", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- local["date"]
@@ -712,8 +710,8 @@ test_that("initialized meta with no rows of data and not overwritten unless dele
 })
 
 test_that("initialized with no rows of data and no metadata and not overwritten unless delete = TRUE", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- local["date"]
@@ -741,8 +739,8 @@ test_that("initialized with no rows of data and no metadata and not overwritten
 })
 
 test_that("initialized with no rows of data and no metadata and not overwritten unless delete = TRUE", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local <- local["date"]
@@ -769,8 +767,8 @@ test_that("initialized with no rows of data and no metadata and not overwritten
 })
 
 test_that("meta then inconsistent data then error meta but delete reset", {
-  conn <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-  teardown(DBI::dbDisconnect(conn))
+
+  conn <- local_conn()
 
   local <- as.data.frame(readwritesqlite:::rws_data_sf)
   local$geometry <- NULL
